==> haskell-cipher-aes-0.2.11-42-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-75irh8Obf7O2UJz3ANsitQ
key: cipher-aes-0.2.11-75irh8Obf7O2UJz3ANsitQ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Cipher.AES
abi: 0252fb7aecb6ac138eccb83302a06131
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-75irh8Obf7O2UJz3ANsitQ
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    securemem-0.1.10-L77sH4fmqw2EtZ4J3Bk3BG
    crypto-cipher-types-0.0.9-3idoBH1GDWKJJFOmzFKhX8
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             securemem-0.1.10-L77sH4fmqw2EtZ4J3Bk3BG=53c0cac37d277622337eb0f549b6b95c
             crypto-cipher-types-0.0.9-3idoBH1GDWKJJFOmzFKhX8=8236dbbd9313f8deee06312785f4b7cc
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes-0.2.11-56-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-5sNPyOQiyxdFTIpHdk5b1m
key: cipher-aes-0.2.11-5sNPyOQiyxdFTIpHdk5b1m
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
abi: d188c89b53dc8260f3617e1e188ac234
exposed: True
exposed-modules:
    Crypto.Cipher.AES
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-5sNPyOQiyxdFTIpHdk5b1m
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY
    securemem-0.1.10-1S3TO7XVNlX6rp8CclufFY
    crypto-cipher-types-0.0.9-7uztzSRso0jFHBxa6bfNuo
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=cdb4e7359967ea10cd00ae1d3fab6945
             securemem-0.1.10-1S3TO7XVNlX6rp8CclufFY=cb6729a72cff77fc11f938a75457318a
             crypto-cipher-types-0.0.9-7uztzSRso0jFHBxa6bfNuo=b9f4f5dc53ef871c5cbd56fbd278ac24
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
